| data |
pl.DataFrame | pd.DataFrame | None |
Visualization data. |
None |
| taxid_col |
str |
Name of the data column with taxonomy ids. By default 'taxid' |
'taxid' |
| width |
int | str |
Lifemap visualization width, in pixels or CSS units. By default DEFAULT_WIDTH |
DEFAULT_WIDTH |
| height |
int | str |
Lifemap visualization height, in pixels or CSS units. By default DEFAULT_HEIGHT |
DEFAULT_HEIGHT |
| center |
Literal['default', 'auto'] | int |
Lifemap initial center. Can be 'default' (tree center), 'auto' (center on data) or a taxid value. Defaults to 'default'. |
'default' |
| zoom |
int | float | None |
Lifemap initial zoom level, if not specified, it is computed depending on the center argument value. Defaults to None. |
None |
| theme |
str |
Color theme for the basemap. Can be one of 'light', 'dark', 'lightblue', 'lightgrey', or 'lightgreen'. Defaults to 'dark'. |
'dark' |
| controls |
Sequence[str] |
List of controls to be displayed on the widget. By default all controls are displayed. Available controls are: - 'zoom': zoom in and zoom out buttons - 'reset_zoom': zoom reset button - 'export': button to export current view to a PNG file - 'search': taxa search button - 'settings': settings button - 'full_screen': full screen toggle button |
('zoom', 'reset_zoom', 'export', 'search', 'settings', 'full_screen') |
| legend_width |
int | None |
Legend width in pixels. By default None. |
None |
| hide_labels |
bool |
If True, hide the taxa name labels. Defaults to False. |
False |
| hide_legend |
bool |
If True, hide the map legend, if any. Defaults to False. |
False |